<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       23.11.13
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com - Yves Hoppe. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 * @since      1.0.0
 */

defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.controller');
jimport( 'joomla.application.component.controlleradmin' );

/**
 * Class TilesControllerGalleries
 *
 * @since  1.0.0
 */
class TilesControllerGalleries extends JControllerAdmin
{
	/**
	 * The constructor
	 */
	public function __construct()
	{
		parent::__construct();

		// Register Extra tasks
		$this->registerTask('unpublish', 'publish');
		$this->registerTask('addGallery', 'editGallery');
		$this->registerTask('apply', 'save');
	}

	/**
	 * Method to get a model object, loading it if required.
	 *
	 * @param   string  $name    The model name. Optional.
	 * @param   string  $prefix  The class prefix. Optional.
	 * @param   array   $config  Configuration array for model. Optional.
	 *
	 * @return  object  The model.
	 */
	public function getModel($name = 'Galleries', $prefix = 'TilesModel', $config = array('ignore_request' => true))
	{
		$model = parent::getModel($name, $prefix, $config);

		return $model;
	}

	/**
	 * Removes a Gallery
	 *
	 * @throws  Exception
	 * @return  void
	 */
	public function remove()
	{
		$cid = JFactory::getApplication()->input->get('cid', array(), '', 'array');
		$db = JFactory::getDBO();

		if (count($cid))
		{
			$cids = implode(',', $cid);
			$query = "DELETE FROM #__tiles_galleries where id IN ( $cids )";
			$db->setQuery($query);

			if (!$db->execute())
			{
				throw new Exception($db->getErrorMsg(), 42);
			}
		}

		$this->setRedirect('index.php?option=com_tiles&controller=galleries');
	}

	/**
	 * Toogles publish for the given tax ids
	 *
	 * @throws  Exception - If db queries fail
	 * @return  void
	 */
	public function publish()
	{
		$cid = JFactory::getApplication()->input->get('cid', array(), '', 'array');

		if ($this->task == 'publish')
		{
			$publish = 1;
		}
		else
		{
			$publish = 0;
		}

		$msg = "";
		$tilesTable = JTable::getInstance('galleries', 'Table');
		$tilesTable->publish($cid, $publish);

		$link = 'index.php?option=com_tiles&view=galleries';

		$this->setRedirect($link, $msg);
	}

	/**
	 * Edit Gallery
	 *
	 * @return  void
	 */
	public function editGallery()
	{
		$document = JFactory::getDocument();
		$viewName = 'editgallery';
		$viewType = $document->getType();
		$view = $this->getView($viewName, $viewType);
		$model = $this->getModel('editgallery');
		$view->setModel($model, true);
		$view->setLayout('default');
		$view->display();
	}

	/**
	 * Saves the form
	 *
	 * @throws  exception - if query fails
	 * @return  void
	 */
	public function save()
	{
		$row = JTable::getInstance('galleries', 'Table');
		$postgal = JRequest::get("post");

		$id = JFactory::getApplication()->input->getInt('id', 0);

		if (!$row->bind($postgal))
		{
			throw new Exception($row->getError(), 42);
		}

		if (!isset($row->published))
		{
			$row->published = 1;
		}

		if (!$row->store())
		{
			throw new Exception($row->getError(), 42);
		}

		switch ($this->task)
		{
			case 'apply':
				$msg = JText::_('COM_TILES_GALLERY_APPLY');
				$link = 'index.php?option=com_tiles&task=galleries.editGallery&id=' . $row->id;
				break;

			case 'save':
			default:
				$msg = JText::_('COM_TILES_GALLERY_SAVE');
				$link = 'index.php?option=com_tiles&view=galleries';
				break;
		}

		$this->setRedirect($link, $msg);
	}

	/**
	 * Cancels gallery edit
	 *
	 * @return  void
	 */
	public function cancel()
	{
		$link = 'index.php?option=com_tiles&view=galleries';
		$this->setRedirect($link);
	}
}
