<?php
/**
 * Tiles
 * @package  Joomla!
 * @Copyright (C) 2012 - Yves Hoppe - compojoom.com
 * @All      rights reserved
 * @Joomla   ! is Free Software
 * @Released under GNU/GPL License : http://www.gnu.org/copyleft/gpl.html
 * @version  $Revision: 0.9.0 beta $
 **/
defined('_JEXEC') or die('Restricted access');


class TilesHelperAdmin
{

	private static $instance;

	/**
	 * @static
	 *
	 * @param $galleryId
	 *
	 * @return mixed
	 */
	public static function countTileElements($galleryId)
	{
		$db = JFactory::getDBO();
		$query = 'SELECT COUNT(*) AS ct FROM #__tiles_elements WHERE galleryId = ' . $galleryId;

		//echo $query;

		$db->setQuery($query);
		$count = $db->loadObjectList();


		return $count[0]->ct;
	}

	/**
	 * @param $gal
	 *
	 * @return mixed
	 */
	public static function calculateHolderHeight($gal)
	{
		// ++ margin, description etc.
		return ($gal->tiles_fields_vertical * 70) + 40;
	}

	/**
	 * @param $gal
	 *
	 * @return mixed
	 */
	public static function calculateTileShowHeight($gal)
	{
		return ($gal->tiles_fields_vertical * 70);
	}

	/**
	 * @param $gal
	 *
	 * @return float
	 */
	public static function calculateSingleTileWidth($gal)
	{
		return round(100 / $gal->tiles_fields_horizontal, 2);
	}

	/**
	 * @static
	 *
	 * @param $at
	 *
	 * @return string
	 */
	public static function getATileBg($at)
	{
		$type = $at->background_type;

		switch ($type)
		{
			case 'color':
				return $at->background;
			case 'image':
				// ../ because of administrator/
				return "url(../" . $at->background . ") " . TilesHelperSettings::getSettings('tiles_backgroundimage_options', 'repeat');
			case 'gradient':
				return "";
			default:
				return $at->background;

		}
	}

	/**
	 * @param $tile
	 * @param $gal
	 *
	 * @return string
	 */
	public static function getATileStyle($tile, $gal)
	{
		$width = $tile->width * TilesHelperAdmin::calculateSingleTileWidth($gal);
		$height = $tile->height * 70;

		$style = "width: " . $width . "%; ";
		$style .= "height: " . $height . "px; ";

		$tmp = explode(",", $tile->position);
		$x = trim($tmp[0]);
		$y = trim($tmp[1]);

		$left = $x * TilesHelperAdmin::calculateSingleTileWidth($gal);
		$top = $y * 70;

		$style .= "left: " . $left . "%;";
		$style .= "top: " . $top . "px;";

		// Background moved to inner

		return $style;
	}

	/**
	 * @param $tile
	 * @param $gal
	 *
	 * @return string
	 */

	public static function getATileStyleUnplaced($tile, $gal)
	{
		$width = $tile->width * 70;
		$height = $tile->height * 60;

		$style = "width: " . $width . "px; ";
		$style .= "height: " . $height . "px; ";

		// Background moved to inner

		return $style;
	}

	/**
	 * @param $tile
	 * @param $gal
	 *
	 * @return string
	 */
	public static function getATileStyleINner($tile, $gal)
	{
		$style = "";
		if ($tile->fontcolor != '')
			$style .= "color: " . $tile->fontcolor . ";";

		// Moved to inner
		$style .= "background: " . TilesHelperAdmin::getATileBg($tile) . ";";
		return $style;
	}

	/**
	 * @static
	 *
	 * @param $tiles
	 *
	 * @return string
	 */
	public static function generateTilesJSDrop($tiles)
	{

		if (empty($tiles))
			return;

		$html = "";

		for ($i = 0; $i < count($tiles); $i++)
		{
			$t = $tiles[$i];

			if ($t->position != null)
			{
				$html .= "new Drag.Move($('tile_element_" . $t->id . "'), {\n";
				$html .= "  container: $('dropable_holder'),\n";
				$html .= "  droppables: $$('.tb_drawer_empty'),\n";
				$html .= "  onEnter: function(element, droppable){\n";
				$html .= "    droppable.setStyle('background', '#E79D35');\n";
				$html .= "  },\n";
				$html .= "  onLeave: function(element, droppable){\n";
				$html .= "      droppable.setStyle('background', '#6B7B95');\n";
				$html .= "  },\n";
				$html .= "  onDrop: function(element, droppable){\n";
				$html .= "  if (droppable) droppable.setStyle('background', '#C17878');\n";
				$html .= "  }\n";
				//        $html .= "};";
				$html .= "});\n";
			}
		}

		return $html;

	}


	/**
	 * @param $vec
	 * @param $y
	 * @param $x
	 */
	public static function isElementHolderPopulated($vec, $y, $x)
	{
		return $vec[$y][$x];
	}

	/**
	 * It makes me wanna spew!!1
	 *
	 * @param $gal
	 * @param $tiles
	 * @param $x
	 * @param $y
	 *
	 * @return array
	 */
	public static function generateElementMap($gal, $tiles)
	{
		$vec = null;

		// Creatign an empty vector map
		for ($i = 0; $i < $gal->tiles_fields_vertical; $i++)
		{
			for ($j = 0; $j < $gal->tiles_fields_horizontal; $j++)
			{
				$vec[$i][$j] = false;
			}
		}

		for ($i = 0; $i < count($tiles); $i++)
		{
			if ($tiles[$i]->position != null)
			{
				$tmp = explode(",", $tiles[$i]->position);
				// The beginning coordinates
				$y = trim($tmp[1]);
				$x = trim($tmp[0]);

				$vec[$y][$x] = true;

				$height = $tiles[$i]->height;
				$width = $tiles[$i]->width;


				// Expanding coords
				for ($j = 0; $j < $height; $j++)
				{
					// one down
					$vec[($y + $j)][$x] = true;
					for ($k = 0; $k < $width; $k++)
					{
						$vec[($y + $j)][($x + $k)] = true;
					}
				}
			}
		}

		return $vec;
	}

	/**
	 * @static
	 *
	 * @param AGallery $gallery
	 *
	 * @return string
	 */
	public static function getAGalleryLayout($gallery)
	{
		$html = "";

		$html .= JText::_('COM_TILES_GALLERY_WIDTH') . ": " . $gallery->tiles_width . ", ";
		$html .= JText::_('COM_TILES_GALLERY_HEIGHT') . ": " . $gallery->tiles_height . ", ";
		$html .= JText::_('COM_TILES_GALLERY_FIELDS_HORIZONTAL') . ": " . $gallery->tiles_fields_horizontal . ", ";
		$html .= JText::_('COM_TILES_GALLERY_FIELDS_VERTICAL') . ": " . $gallery->tiles_fields_vertical;

		return $html;
	}
}
