<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       23.11.13
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com - Yves Hoppe. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 * @since      1.0.0
 */

defined('_JEXEC') or die;

// Load Helpers
require_once JPATH_ADMINISTRATOR . '/components/com_tiles/elements/atile.php';

JTable::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_tiles/tables');

/**
 * Class TilesHelperUtils
 *
 * @since  1.0.0
 */
class TilesHelperUtils
{
	private static $instance;

	private static $gallery;

	/**
	 * Gets the template name
	 *
	 * @param   int  $num  - The template id
	 *
	 * @return  string
	 */
	public static function getTemplateName($num)
	{
		switch ($num)
		{
			case 1:
				return "modern";
			case 2:
				return "spacy";
			default:
				return "default";
		}
	}

	/**
	 * Loads the tiles from the database
	 *
	 * @param   int     $galleryid  - The gallery id
	 * @param   string  $lang       - The language
	 *
	 * @return  array
	 */
	public static function loadTiles($galleryid, $lang = null)
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('*')->from('#__tiles_elements')
			->where(
				array('galleryId  = ' . $db->quote($galleryid),
				'published = 1')
			);

		if ($lang != null)
		{
			$query->where('lang = ' . $db->quote($lang));
		}

		$db->setQuery($query);
		$tile_elements = $db->loadObjectList();
		$tiles = array();

		// TODO: Change to ORM mapping....
		if ($tile_elements)
		{
			foreach ($tile_elements as $tile)
			{
				$tmp = new ATile;
				$tmp->background = $tile->background;
				$tmp->galleryId = $galleryid;
				$tmp->background_type = $tile->background_type;
				$tmp->fontcolor = $tile->fontcolor;
				$tmp->linkcolor = $tile->linkcolor;
				$tmp->height = $tile->height;
				$tmp->id = $tile->id;
				$tmp->linktype = $tile->linktype;
				$tmp->link = $tile->link;
				$tmp->linktitle = $tile->linktitle;
				$tmp->overlay = $tile->overlay;
				$tmp->height = $tile->height;
				$tmp->position = $tile->position;
				$tmp->text = $tile->text;
				$tmp->tilename = $tile->tilename;
				$tmp->title = $tile->title;
				$tmp->width = $tile->width;

				$tiles[] = $tmp;
			}
		}

		return $tiles;
	}

	/**
	 * Gets the galleries
	 *
	 * @param   int  $published  - Published
	 *
	 * @return mixed
	 */
	public static function loadGalleries($published = null)
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('*')->from('#__tiles_galleries');

		if ($published != null)
		{
			$query->where('published = 1');
		}

		$db->setQuery($query);
		$galleries = $db->loadObjectList();

		return $galleries;
	}

	/**
	 * Gets a single tile
	 *
	 * @param   int  $id  - The id
	 *
	 * @return  mixed
	 */
	public static function getATile($id)
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('*')->from('#__tiles_elements ')
			->where('id = ' . $db->quote($id));

		$db->setQuery($query);
		$tile = $db->loadObject();

		return $tile;
	}

	/**
	 * Gets the gallery
	 *
	 * @param   int  $galleryId  - The id
	 *
	 * @return  mixed
	 */
	public static function getGallery($galleryId)
	{
		if (!isset(self::$gallery[$galleryId]))
		{
			$db = JFactory::getDBO();
			$query = $db->getQuery(true);
			$query->select('*')->from('#__tiles_galleries')->where('id = ' . $galleryId);

			$db->setQuery($query);
			self::$gallery[$galleryId] = $db->loadObject();
		}

		return self::$gallery[$galleryId];
	}

	/**
	 * Loads the gallery settings
	 *
	 * @param   int     $galleryId  - The gallery id
	 * @param   string  $which      - The which
	 * @param   string  $default    - The default
	 *
	 * @return  string
	 */
	public static function getGallerySetting($galleryId, $which, $default = null)
	{
		$gallery = self::getGallery($galleryId);

		switch ($which)
		{
			case 'tiles_width':
				return self::checkGallerySetting($gallery->tiles_width, $default);

			case 'tiles_height':
				return self::checkGallerySetting($gallery->tiles_height, $default);

			case 'tiles_fields_horizontal':
				return self::checkGallerySetting($gallery->tiles_fields_horizontal, $default);

			case 'tiles_fields_vertical':
				return self::checkGallerySetting($gallery->tiles_fields_vertical, $default);

			case 'tiles_fields_horizontal_visible':
				return self::checkGallerySetting($gallery->tiles_fields_horizontal_visible, $default);

			case 'color_profile':
				return self::checkGallerySetting($gallery->color_profile, $default);

			case 'color_profile_custom':
				return self::checkGallerySetting($gallery->color_profile_custom, $default);

			case 'single_tile_element_width':
				return self::checkGallerySetting($gallery->single_tile_element_width, $default);

			default:
				return $default;
		}
	}

	/**
	 * Gets a setting
	 *
	 * @param   string  $setting  - The key
	 * @param   string  $default  - The default val
	 *
	 * @return null
	 */
	private static function checkGallerySetting($setting, $default = null)
	{
		if (empty ($setting))
		{
			return $default;
		}
		else
		{
			return $setting;
		}
	}

	/**
	 * Converts an rgba color
	 *
	 * @param   string  $rgba  - An comma separated array string
	 *
	 * @return  string
	 */
	public static function rgb2html($rgba)
	{
		$tmp = explode(",", $rgba);
		$r = $tmp[0];
		$g = $tmp[1];
		$b = $tmp[2];
		$a = $tmp[3];

		return self::rgba2html($r, $g, $b, $a);
	}

	/**
	 * Gets the html color from rgba
	 *
	 * @param   int  $r  - red
	 * @param   int  $g  - green
	 * @param   int  $b  - blue
	 * @param   int  $a  - alpha
	 *
	 * @return  string
	 */
	public static function rgba2html($r, $g = -1, $b = -1, $a = -1)
	{
		if (is_array($r) && count($r) == 3)
		{
			list($r, $g, $b) = $r;
		}

		$r = intval($r);
		$g = intval($g);
		$b = intval($b);

		$r = dechex($r < 0 ? 0 : ($r > 255 ? 255 : $r));
		$g = dechex($g < 0 ? 0 : ($g > 255 ? 255 : $g));
		$b = dechex($b < 0 ? 0 : ($b > 255 ? 255 : $b));

		if ($a != -1)
		{
			$a = dechex($a < 0 ? 0 : ($a > 255 ? 255 : $a));
		}

		$color = "";

		if ($a != -1)
		{
			if ($a == 0)
			{
				$color .= "00";
			}
			elseif ($a == 1)
			{
				// Nothing
			}
			else
			{
				$color .= (strlen($a) < 2 ? '0' : '') . $a;
			}
		}

		$color .= (strlen($r) < 2 ? '0' : '') . $r;
		$color .= (strlen($g) < 2 ? '0' : '') . $g;
		$color .= (strlen($b) < 2 ? '0' : '') . $b;

		return '#' . $color;
	}

	/**
	 * Converts an html color to rgba
	 *
	 * @param   string  $color  - The color
	 *
	 * @return array|bool
	 */
	public static function html2rgb($color)
	{
		if ($color[0] == '#')
		{
			$color = substr($color, 1);
		}

		if (strlen($color) == 6)
		{
			list($r, $g, $b) = array($color[0] . $color[1],
				$color[2] . $color[3],
				$color[4] . $color[5]);
		}
		elseif (strlen($color) == 3)
		{
			list($r, $g, $b) = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
		}
		else
		{
			return false;
		}

		$r = hexdec($r);
		$g = hexdec($g);
		$b = hexdec($b);

		return array($r, $g, $b);
	}

	/**
	 * Show copyright
	 *
	 * @param   bool  $frontend  - Are we in the frontend
	 *
	 * @return  string
	 */
	public static function getCopyright($frontend = true)
	{
		$html = "";

		// Always show in the backend
		if (TilesHelperSettings::getSettings('frontend_showfooter', 1) == 1 || $frontend == false)
		{
			$html = "<div id=\"copyright_box\" align=\"center\" style=\"margin-top: 20px;\">
           <a href=\"https://compojoom.com/joomla-extensions/tiles\" target=\"_new\">Tiles</a> for <a href=\"http://joomla.org\">Joomla!™</a>
           by <a href=\"https://compojoom.com\" target=\"_new\">compojoom.com</a>
           </div>";
		}

		return $html;
	}


	/**
	 * Generates the menu
	 *
	 * @return  array
	 */
	public static function getMenu()
	{
		$menu = array(
			'dashboard' => array(
				'link' => '', 'title' => 'COM_TILES_DASHBOARD', 'icon' => 'fa-dashboard', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'dashboard home overview'
			),

			'elements' => array(
				'link' => '', 'title' => 'COM_TILES_ELEMENTS', 'icon' => 'fa-puzzle-piece', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'elements tiles'
			),

			'galleries' => array(
				'link' => '', 'title' => 'COM_TILES_GALLERIES', 'icon' => 'fa-picture-o', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'gallery galleries'
			)
		);

		return $menu;
	}
}
