<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       10.10.14
 *
 * @copyright  Copyright (C) 2008 - 2014 Yves Hoppe - compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_BASE') or die;

jimport('joomla.form.formfield');

/**
 * Supports a modal gallery picker.
 *
 * @since  2.0
 */
class JFormFieldModal_Gallery extends JFormField
{
	/**
	 * The form field type.
	 *
	 * @var                string
	 * @since        1.6
	 */
	protected $type = 'Modal_Gallery';

	/**
	 * Method to get the field input markup.
	 *
	 * @return   string  The field input markup.
	 */
	protected function getInput()
	{
		// Load the modal behavior script.
		JHtml::_('behavior.modal', 'a.modal');

		$db        = JFactory::getDBO();
		$db->setQuery(
			'SELECT gallery_name' .
			' FROM #__tiles_galleries' .
			' WHERE id = ' . (int) $this->value
		);

		$title = $db->loadResult();

		if ($error = $db->getErrorMsg())
		{
			JError::raiseWarning(500, $error);
		}

		if (empty($title))
		{
			$title = JText::_('COM_TILES_SELECT_GALLERY');
		}

		$title = htmlspecialchars($title, ENT_QUOTES, 'UTF-8');

		//                $script = array();
		$script[] = '        function selectGallery(id, title, object) {';
		$script[] = '                document.id("' . $this->id . '_id").value = id;';
		$script[] = '                document.id("' . $this->id . '_name").value = title;';
		$script[] = '                SqueezeBox.close();';
		$script[] = '        }';

		// Add the script to the document head.
		JFactory::getDocument()->addScriptDeclaration(implode("\n", $script));

		$link = 'index.php?option=com_tiles&amp;view=galleries&layout=element&amp;tmpl=component&amp;object=' . $this->name;

		$html[] = '<div class="fltlft">';
		$html[] = ' <input type="text" id="' . $this->id . '_name" value="' . $title . '" disabled="disabled" size="35" />';
		$html[] = '</div>';

		// The user select button.
		$html[] = '<div class="button2-left">';
		$html[] = '  <div class="blank">';
		$html[] = '        <a class="modal" title="' . JText::_('COM_CONTENT_CHANGE_ARTICLE') . '"  href="'
			. $link . '" rel="{handler: \'iframe\', size: {x: 800, y: 450}}">' . JText::_('COM_TILES_SELECT_GALLERY') . '</a>';
		$html[] = '  </div>';
		$html[] = '</div>';

		// The active article id field.
		if (0 == (int) $this->value)
		{
			$value = '';
		}
		else
		{
			$value = (int) $this->value;
		}

		// Class='required' for client side validation
		$class = '';

		if ($this->required)
		{
			$class = ' class="required modal-value"';
		}

		$html[] = '<input type="hidden" id="' . $this->id . '_id"' . $class . ' name="' . $this->name . '" value="' . $value . '" />';

		return implode("\n", $html);
	}
}
