<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       10.10.14
 *
 * @copyright  Copyright (C) 2008 - 2014 Yves Hoppe - compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

// no direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.model');

class modTilesHelper
{
	private static $instance;

	/**
	 * @static
	 * @return float
	 */
	public static function getTileWidth($galleryid)
	{
		return TilesHelperUtils::getGallerySetting($galleryid, 'single_tile_element_width', 200);
	}

	/**
	 * @static
	 * @return float
	 */
	public static function getVisibleWidth($galleryid)
	{
		return 100 / TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal_visible', 4);
	}

	/**
	 * @static
	 * @return float
	 */
	public static function getTileHeightPixel($galleryid)
	{
		return TilesHelperUtils::getGallerySetting($galleryid, 'tiles_height', 300)
		/ TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_vertical', 2);
	}

	/**
	 * @static
	 * @return float
	 */
	public static function getTileHeightPercent($galleryid)
	{
		return 100 / TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_vertical', 2);
	}

	/**
	 * @param ATile $at
	 *
	 * @return int
	 */
	public static function getATileWidth(ATile $at)
	{
		$single = TilesHelperUtils::getGallerySetting($at->galleryId, 'single_tile_element_width', 200);

		return $at->width * $single;
	}


	/**
	 * @static
	 *
	 * @param ATile $at
	 *
	 * @return int
	 */
	public static function getATileHeightinPercent(ATile $at)
	{
		return $at->height * modTilesHelper::getTileHeightPercent($at->galleryId);
	}

	/**
	 * @static
	 *
	 * @param ATile $at
	 *
	 * @return int
	 */
	public static function getATileHeightinPixel(ATile $at)
	{
		return $at->height * modTilesHelper::getTileHeightPixel($at->galleryId);
	}

	public static function getATilePositionPercent(ATile $at)
	{
		$positions = explode(",", $at->position);

		$left = modTilesHelper::getTileWidth($at->galleryId) * $positions[0];
		$top  = modTilesHelper::getTileHeightPixel($at->galleryId) * $positions[1];

		return array($left, $top);
	}

	/**
	 * @static
	 * @return mixed
	 */
	public static function getTileShowWidth($galleryid)
	{
		return (modTilesHelper::getVisibleWidth($galleryid) *
			TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12)) * 0.8;
	}

	/**
	 * @static
	 *
	 * @param $galleryid
	 *
	 * @return mixed
	 */
	public static function getTilesMaxLeft($galleryid)
	{
		// showwidth240
		$showwidth = modTilesHelper::getTileShowWidth($galleryid) - 30;
		// 3
		$viswidthpercent = TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12) /
			TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal_visible', 4);

		// 240 - (240 / 3) = 240 - 80 = 160
		// return -($showwidth - ($showwidth / $viswidthpercent));

		$single = self::getTileWidth($galleryid);
		$fields = TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12);

		return ($single * $fields);
	}

	/**
	 * @static
	 * @return float
	 */
	public static function getTileShowStartPositionPercent($galleryid)
	{
		// showwidth240
		$showwidth = modTilesHelper::getTileShowWidth($galleryid) - 30;
		// 3
		$viswidthpercent = TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12) /
			TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal_visible', 4);

		// 240 - (240 / 3) = 240 - 80 = 160
		return -(($showwidth - ($showwidth / $viswidthpercent)) / 2);
	}

	/**
	 * @static
	 *
	 * @param $galleryid
	 *
	 * @return float
	 */
	public static function getStepWidth($galleryid, $maxleft)
	{
		//$showwidth = modTilesHelper::getTileShowWidth($galleryid) -30;

		//$stepwidth = $showwidth / TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12);

		//return($stepwidth * 2);

		// 320 / 16 = 20

		// 16 / 4 = 4 || 12 / 4 = 3 |||
		$jumps = TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal', 12)
			/ TilesHelperUtils::getGallerySetting($galleryid, 'tiles_fields_horizontal_visible', 4);

		if ($jumps == 3)
			$jumps = 2; // stupid hack!!! fix that

		// return modTilesHelper::getTileWidthPercent($galleryid) * 2;

		return ($maxleft * -1 / $jumps);
	}

	/**
	 * @static
	 *
	 * @param $at
	 *
	 * @return string
	 */
	public static function getATileBackground($at)
	{
		$type = $at->background_type;

		switch ($type)
		{
			case 'color':
				return $at->background;
			case 'image':
				return "url(" . $at->background . ") " . TilesHelperSettings::getSettings('tiles_backgroundimage_options', 'repeat');
			case 'gradient':
				return "";
			default:
				return $at->background;

		}
	}

	/**
	 * @static
	 *
	 * @param $at
	 *
	 * @return string
	 */
	public static function getATileStyle($at)
	{
		$style = "width: " . modTilesHelper::getATileWidth($at) . "px;";

		$style .= "height: " . modTilesHelper::getATileHeightinPixel($at) . "px;";

		$tpos = modTilesHelper::getATilePositionPercent($at);

		$style .= "left: " . $tpos[0] . "px;";
		$style .= "top: " . $tpos[1] . "px;";

		if ($at->fontcolor != '')
		{
			$style .= "color: " . $at->fontcolor . ";";
		}

		return $style;
	}

	/**
	 * @static
	 *
	 * @param $tileoverlay
	 *
	 * @return string
	 */
	public static function getATileOverlay($tileoverlay)
	{
		//if(preg_match("//", $tileoverlay)){

		// TODO add options like background color or image and transparency
		return $tileoverlay;
	}

	/**
	 * @static
	 *
	 * @param $atile
	 *
	 * @return string
	 */
	public static function getATileLink($tile)
	{
		// echo $tile->linktype;

		if ($tile->linktype == 'absolute')
		{
			if (!empty($tile->link))
			{
				// Stupid hardcoded solution for link array
				$links     = explode(";", $tile->link);
				$firstlink = $links[0];
				$title     = explode(";", $tile->linktitle);

				$html = '<a href="' . $firstlink . '" title="' . $title[0] . '" class="tiles_absolute_link"></a>';

				return $html;
			}
		}
		else if ($tile->linktype == 'buttons')
		{
			if (!empty($tile->link))
			{

				$html = '<p class="tiles_buttons">';
				$btns = explode(";", $tile->link);
				$caps = explode(";", $tile->linktitle);
				//echo "Buttons: " .count($btns);
				if (count($btns) == 1)
				{
					// One Button
					$html .= '<a href="' . $tile->link . '" class="tiles_button tiles_button_single">' . $tile->linktitle . '</a>';
				}
				else if (count($btns) == 2)
				{
					// Left Right button
					$html .= '<a href="' . $btns[0] . '" class="tiles_button tiles_button_left">' . $caps[0] . '</a>' . "\n";
					$html .= '<a href="' . $btns[1] . '" class="tiles_button tiles_button_right">' . $caps[1] . '</a>' . "\n";
				}
				else
				{
					// More buttons?!
					for ($i = 0; $i < count($btns); $i++)
					{
						if ($i != count($btns) - 1)
						{
							$html .= '<a href="' . $btns[$i] . '" class="tiles_button tiles_button_multi">' . $caps[$i] . '</a>';
						}
						else
						{
							$html .= '<a href="' . $btns[$i] . '" class="tiles_button tiles_button_last">' . $caps[$i] . '</a>';
						}
					}
				}

				$html .= "</p>";

				return $html;

			}
		}
		else if ($tile->linktype == 'none')
		{
			return "";
		}

		// Fallback
		return "";
	}

	/**
	 * @static
	 *
	 * @param $at
	 *
	 * @return string
	 */
	public static function getATileInnerStyle($at)
	{
		// Calculating real height, after padding
		$height = modTilesHelper::getATileHeightinPixel($at) - (TilesHelperSettings::getSettings('tiles_margin', '5') * 2)
			- (TilesHelperSettings::getSettings('tiles_padding', '20') * 2);

		$style = "height: " . $height . "px;";
		//$style .= "margin: " .SettingsHelper::getSettings('tiles_margin', '5') . "px;";
		$style .= "background: " . modTilesHelper::getATileBackground($at) . ";";

		return $style;
	}

	/**
	 * @static
	 *
	 * @param $at
	 *
	 * @return string
	 */
	public static function getATileInnerStyleModern($at)
	{
		// Calculating real height, after padding
		//$height = modTilesHelper::getATileHeightinPixel($at)-(TilesHelperSettings::getSettings('tiles_padding', '20') * 2);

		$height = modTilesHelper::getATileHeightinPixel($at);
		$style  = "height: " . $height . "px;";
		//$style .= "margin: " .SettingsHelper::getSettings('tiles_margin', '5') . "px;";
		$style .= "background: " . modTilesHelper::getATileBackground($at) . ";";

		return $style;
	}


	/**
	 * @static
	 *
	 * @param $which
	 * @param $maxleft
	 *
	 * @return string
	 */
	public static function generateJavaScript($which, $maxleft, $duration = 600,
	                                          $effect = "Fx.Transitions.Expo.easeIn", $stepwidth = 35, $module_id = 1)
	{
		// Transition effect
		if ($which == 0)
		{
			$domready = "window.addEvent('domready', function(){ \n";
			$domready .= "  var holder = $('tiles_holder_" . $module_id . "');";
			$domready .= "  var scroller = holder.getElement('.tiles_scroller');";
			$domready .= "  var btn_scroll_left = holder.getElement('.btn_scroll_left');";
			$domready .= "  var btn_scroll_right = holder.getElement('.btn_scroll_right');";
			$domready .= "  var tiles_left_control = holder.getElement('.tiles_left_control');";
			$domready .= "  var tiles_right_control = holder.getElement('.tiles_right_control');";
			$domready .= "  var fx = new Fx.Morph(scroller, {
                    duration: " . $duration . ",
                    transition: " . $effect . ",
                    unit: '%',
                    onComplete: function(){

                          if(scroller.getStyle('left').toFloat() >= 0) {
                             new Fx.Morph(tiles_left_control, {duration: 500, onComplete:
                                            function(){tiles_left_control.setStyle('display','none');}}).start({'opacity': 0});
                          }

                          if(scroller.getStyle('left').toFloat() < 0) {
                             tiles_left_control.setStyle('display','block');
                             new Fx.Morph(tiles_left_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});
                          }

                          if(scroller.getStyle('left').toFloat() <= " . $maxleft . ") {
                             new Fx.Morph(tiles_right_control, {duration: 500, onComplete:
                                            function(){tiles_right_control.setStyle('display','none');}}).start({'opacity': 0});
                          }

                          if(scroller.getStyle('left').toFloat() > " . $maxleft . ") {
                             tiles_right_control.setStyle('display','block');
                             new Fx.Morph(tiles_right_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});
                          }
                    }
                 });";

			$domready .= "  btn_scroll_left.addEvent('mousedown', function(event){";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			$domready .= "      if(current_left < 0){";
			$domready .= "          fx.start({
                                        left: current_left + " . $stepwidth . "
                                    });";
			$domready .= "      }";
			$domready .= "  });";

			$domready .= "  btn_scroll_left.addEvent('click', function(event){";
			$domready .= "  event.stop();";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('mousedown', function(event){";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			$domready .= "      if(current_left > " . $maxleft . "){";
			$domready .= "          fx.start({
                                        left: current_left - " . $stepwidth . "
                                    });";
			$domready .= "      }";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('click', function(event){";
			$domready .= "  event.stop();";
			$domready .= "  });";

			$domready .= "});";

			return $domready;
		}
		else if ($which == 1)
		{
			// Mouse click transition
			$domready = "window.addEvent('domready', function(){ \n";
			$domready .= "  var holder = $('tiles_holder_" . $module_id . "');";
			$domready .= "  var scroller = holder.getElement('.tiles_scroller');";
			$domready .= "  var btn_scroll_left = holder.getElement('.btn_scroll_left');";
			$domready .= "  var btn_scroll_right = holder.getElement('.btn_scroll_right');";
			$domready .= "  var tiles_left_control = holder.getElement('.tiles_left_control');";
			$domready .= "  var tiles_right_control = holder.getElement('.tiles_right_control');";
			// Scroll left
			$domready .= "  var scrollleft = function() {";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			//$domready .= "      alert(current_left);";
			$domready .= "      if (current_left < 0) {";
			$domready .= "          var new_value = current_left + 1;";
			$domready .= "          scroller.setStyle('left', new_value + '%');";
			$domready .= "      } else {
                                    clearInterval(periodical_left);
                                }
                                if(current_left >= 0) {
                                     new Fx.Morph(tiles_left_control, {duration: 500, onComplete:
                                            function(){tiles_left_control.setStyle('display','none');}}).start({'opacity': 0});
                                }
                                if(current_left > " . $maxleft . ") {
                                     tiles_right_control.setStyle('display','block');
                                     new Fx.Morph(tiles_right_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});
                                }";
			$domready .= "      return scrollleft";
			$domready .= "  };";

			$domready .= "  var scrollright = function() {";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			//$domready .= "      alert(current_left);";
			$domready .= "      if (current_left > " . $maxleft . ") {";
			$domready .= "          var new_value = current_left - 1;";
			$domready .= "          scroller.setStyle('left', new_value + '%');";
			$domready .= "      } else {
                                    clearInterval(periodical_right);
                                }
                                if(current_left < 0) {
                                    tiles_left_control.setStyle('display','block');
                                    new Fx.Morph(tiles_left_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});

                                }
                                if(current_left <= " . $maxleft . ") {
                                    new Fx.Morph(tiles_right_control, {duration: 500, onComplete:
                                            function(){tiles_right_control.setStyle('display','none');}}).start({'opacity': 0});
                                }";
			$domready .= "      return scrollright";
			$domready .= "  };";

			//$domready .= "";
			$domready .= "  btn_scroll_left.addEvent('mousedown', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      periodical_left = scrollleft().periodical(30);";
			$domready .= "  });";

			$domready .= "  btn_scroll_left.addEvent('mouseup', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      clearInterval(periodical_left);";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('mousedown', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      periodical_right = scrollright().periodical(30);";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('mouseup', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      clearInterval(periodical_right);";
			$domready .= "  });";

			// Fixing click event
			$domready .= "  btn_scroll_left.addEvent('click', function(event){";
			$domready .= "      event.stop();";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('click', function(event){";
			$domready .= "      event.stop();";
			$domready .= "  });";

			$domready .= "});";

			return $domready;

		}
		else if ($which == 2)
		{
			// Mouse over scroll
			$domready = "window.addEvent('domready', function(){ \n";
			$domready .= "  var holder = $('tiles_holder_" . $module_id . "');";
			$domready .= "  var scroller = holder.getElement('.tiles_scroller');";
			$domready .= "  var btn_scroll_left = holder.getElement('.btn_scroll_left');";
			$domready .= "  var btn_scroll_right = holder.getElement('.btn_scroll_right');";
			$domready .= "  var tiles_left_control = holder.getElement('.tiles_left_control');";
			$domready .= "  var tiles_right_control = holder.getElement('.tiles_right_control');";

			// Scroll left
			$domready .= "  var scrollleft = function() {";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			//$domready .= "      alert(current_left);";
			$domready .= "      if (current_left < 0) {";
			$domready .= "          var new_value = current_left + 1;";
			$domready .= "          scroller.setStyle('left', new_value + '%');";
			$domready .= "      }
                                if(current_left >= 0) {
                                     new Fx.Morph(tiles_left_control, {duration: 500, onComplete:
                                            function(){tiles_left_control.setStyle('display','none');}}).start({'opacity': 0});
                                }
                                if(current_left > " . $maxleft . ") {
                                     tiles_right_control.setStyle('display','block');
                                     new Fx.Morph(tiles_right_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});
                                }
                                ";
			$domready .= "      return scrollleft";
			$domready .= "  };";

			$domready .= "  var scrollright = function() {";
			$domready .= "      var current_left = scroller.getStyle('left').toFloat();";
			//$domready .= "      alert(current_left);";
			$domready .= "      if (current_left > " . $maxleft . ") {";
			$domready .= "          var new_value = current_left - 1;";
			$domready .= "          scroller.setStyle('left', new_value + '%');";
			$domready .= "      }
                                if(current_left < 0) {
                                    tiles_left_control.setStyle('display','block');
                                    new Fx.Morph(tiles_left_control, {duration: 500, onComplete: function(){}}).start({'opacity': 1});

                                }
                                if(current_left <= " . $maxleft . ") {
                                    new Fx.Morph(tiles_right_control, {duration: 500, onComplete:
                                            function(){tiles_right_control.setStyle('display','none');}}).start({'opacity': 0});
                                }
                                ";
			$domready .= "      return scrollright";
			$domready .= "  };";

			//$domready .= "";
			$domready .= "  btn_scroll_left.addEvent('mouseenter', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      periodical_left = scrollleft().periodical(30);";
			$domready .= "  });";

			$domready .= "  btn_scroll_left.addEvent('mouseleave', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      clearInterval(periodical_left);";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('mouseenter', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      periodical_right = scrollright().periodical(30);";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('mouseleave', function(event){";
			$domready .= "      event.stop();";
			$domready .= "      clearInterval(periodical_right);";
			$domready .= "  });";

			// Fixing click event
			$domready .= "  btn_scroll_left.addEvent('click', function(event){";
			$domready .= "      event.stop();";
			$domready .= "  });";

			$domready .= "  btn_scroll_right.addEvent('click', function(event){";
			$domready .= "      event.stop();";
			$domready .= "  });";

			$domready .= "});";

			return $domready;
		}
	}
}