/*
 * Tiles; v20141010
 * https://compojoom.com
 * Copyright (c) 2012 - 2014 Yves Hoppe - compojoom
 */

(function ($) {

	var version = "20140728";
	var debug = 1;

	$.fn.tiles = function (options) {

		var settings = $.extend({
			// 0 = Transition, 1 = scroll (mousedown), 2 = scroll (mouseover)
			effect: 2,
			maxLeft: -1200,
			stepWidth: 7,
			stepPeriod: 15,
			transitionWidth: 300
		}, options);

		var API = $.extend({
			scrollLeft: function(holder) {
				holder.current_left = holder.scroller.position().left;

				holder.log("left: " + holder.current_left);

				holder.tiles_right_control.show();
				if (holder.current_left < 0)
				{
					if(settings.effect == 0) {
						holder.current_left += settings.transitionWidth;
						if (holder.current_left > 0) {
							holder.current_left = 0;
						}

						holder.scroller.animate({left: holder.current_left}, { complete: function() {
							if(holder.scroller.position().left == 0) {
								holder.tiles_left_control.hide();
							}
						}});
					} else {
						holder.current_left += settings.stepWidth;
						holder.scroller.css({left: holder.current_left});

						if(holder.scroller.position().left == 0) {
							holder.tiles_left_control.hide();
						}
					}
				}
				else
				{
					holder.tiles_left_control.hide();
					holder.current_left = 0;
					holder.scroller.css({left: holder.current_left});

					if (settings.effect != 0) {
						holder.left_timer.cancel();
					}
				}

				return holder.scroll_left;
			},

			scrollRight: function(holder) {
				holder.current_left = holder.scroller.position().left;

				holder.log("right: " + holder.current_left + " max " + settings.maxLeft);

				holder.tiles_left_control.show();

				if (holder.current_left > settings.maxLeft)
				{
					if(settings.effect == 0) {
						holder.current_left -= settings.transitionWidth;
						if (holder.current_left < settings.maxLeft) {
							holder.current_left = settings.maxLeft;
						}

						holder.scroller.animate({left: holder.current_left}, { complete: function() {
								if (holder.scroller.position().left <= settings.maxLeft) {
									holder.tiles_right_control.hide();
								}
							}});
					} else {
						holder.current_left -= settings.stepWidth;
						holder.scroller.css({left: holder.current_left});
						if (holder.scroller.position().left <= settings.maxLeft) {
							holder.tiles_right_control.hide();
						}
					}
				}
				else
				{
					holder.tiles_right_control.hide();
					holder.current_left = settings.maxLeft;
					holder.scroller.css({left: holder.current_left});

					if (settings.effect != 0) {
						holder.right_timer.cancel();
					}
				}
			},

			init: function(holder){
				holder.btn_scroller_left = $("a.btn_scroll_left", holder.tiles_holder);
				holder.btn_scroller_right = $("a.btn_scroll_right", holder.tiles_holder);

				// Container
				holder.tiles_left_control = $(".tiles_left_control", holder.tiles_holder);
				holder.tiles_right_control = $(".tiles_right_control", holder.tiles_holder);

				holder.scroller = $(".tiles_scroller", holder.tiles_holder);

				// Calculate max left
				settings.maxLeft = settings.maxLeft + holder.tiles_holder.innerWidth();

				if (settings.effect == 0) {
					holder.btn_scroller_left.click(function(e){
						e.preventDefault();
						API.scrollLeft(holder);
					});

					holder.btn_scroller_right.click(function(e){
						e.preventDefault();
						API.scrollRight(holder);
					});
				} else if (settings.effect == 2) {
					holder.btn_scroller_left.mouseenter(function(e){
						e.preventDefault();
						holder.left_timer = $.periodic({period: settings.stepPeriod, decay: 0}, function(){
							API.scrollLeft(holder);
						});
					});

					holder.btn_scroller_left.mouseleave(function(e){
						e.preventDefault();
						holder.left_timer.cancel();
					});

					holder.btn_scroller_right.mouseenter(function(e){
						e.preventDefault();
						holder.right_timer = $.periodic({period: settings.stepPeriod, decay: 0}, function(){
							API.scrollRight(holder);
						});
					});

					holder.btn_scroller_right.mouseleave(function(e){
						e.preventDefault();
						holder.right_timer.cancel();
					});
				} else if (settings.effect == 1) {

					holder.btn_scroller_left.mousedown(function(e){
						e.preventDefault();
						holder.left_timer = $.periodic({period: settings.stepPeriod, decay: 0}, function(){
							API.scrollLeft(holder);
						});
					});

					holder.btn_scroller_left.mouseup(function(e){
						e.preventDefault();
						holder.left_timer.cancel();
					});

					// Right
					holder.btn_scroller_right.mousedown(function(e){
						e.preventDefault();
						holder.right_timer = $.periodic({period: settings.stepPeriod, decay: 0}, function(){
							API.scrollRight(holder);
						});
					});

					holder.btn_scroller_right.mouseup(function(e){
						e.preventDefault();
						holder.right_timer.cancel();
					});
				}

				return true;
			}
		});

		return this.each(function () {
			// We need to keep it local
			var holder = {
				log: $.fn.tiles.log,
				tiles_holder: null,
				scroller: null,
				btn_scroller_left: null,
				btn_scroller_right: null,
				tiles_left_control: null,
				tiles_right_control: null,
				current_left: 0,
				left_timer: null,
				right_timer: null
			};

			holder.log('-- Tiles Init --');
			holder.log('-- Version: ' + version + ' --');

			holder.tiles_holder = $(this);
			var success = API.init(holder);

			holder.log('-- Init Status:  ' + success + ' --');
			holder.log('-- Finished loading Tiles --');
		});
	}

	// Logging to console
	$.fn.tiles.log = function log() {
		if (window.console && console.log && debug == 1)
			console.log('[Tiles] ' + Array.prototype.join.call(arguments, ' '));
	}
}(jQuery));