<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       10.10.14
 *
 * @copyright  Copyright (C) 2008 - 2014 Yves Hoppe - compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

defined('_JEXEC') or die;

// Load bootstrap 3 and corresponding JS
if (TilesHelperSettings::getSettings("load_bootstrap", 1))
{
	CompojoomHtmlBehavior::bootstrap31(TilesHelperSettings::getSettings("load_jquery", 1), false, false, false);
}

// Load CSS
JHTML::_('stylesheet', 'media/mod_tiles/templates/default/template.css');

// Load JS
JHTML::_('script', 'media/mod_tiles/js/jquery.periodic.js');
JHTML::_('script', 'media/mod_tiles/js/tiles.jquery.js');

// Load Tiles out of db tilesid = Galleryid
$tiles = TilesHelperUtils::loadTiles($params->get('tilesid', 1));

if ($tiles == null)
{
	JError::raiseError(404, 'MOD_TILES_NO_TILES');
}

$doc = JFactory::getDocument();

$maxleft = modTilesHelper::getTilesMaxLeft($params->get('tilesid', 1));
$stepwidth = modTilesHelper::getStepWidth($params->get('tilesid', 1), $maxleft);

// Generate CSS
$startcolor = TilesHelperSettings::getSettings('control_start_color', '255,255,255,1');
$endcolor = TilesHelperSettings::getSettings('control_end_color', '255,255,255,0');
$iconcolor = TilesHelperSettings::getSettings('icon_color', 'blue');
$padding = TilesHelperSettings::getSettings('tiles_padding', '20');
$margin = TilesHelperSettings::getSettings('tiles_margin', '5');

// 0 = Transition, 1 = scroll (mousedown), 2 = scroll (mouseover)
$effect = $params->get("scroll_effect", 0);
?>
<style type="text/css">
	.tiles_left_control {
		position: absolute;
		z-index: 4;
		width: 10%;
		left: 0;
		top: 0;
		cursor: pointer;
		background: -moz-linear-gradient(left, rgba(<?php echo $startcolor; ?>) 0%, rgba(<?php echo $endcolor; ?>) 100%); /* FF3.6+ */
		background: -webkit-gradient(linear, left top, right top, color-stop(0%, rgba(<?php echo $startcolor; ?>)), color-stop(100%, rgba(<?php echo $endcolor; ?>))); /* Chrome,Safari4+ */
		background: -webkit-linear-gradient(left, rgba(<?php echo $startcolor; ?>) 0%, rgba(<?php echo $endcolor; ?>) 100%); /* Chrome10+,Safari5.1+ */
		background: -o-linear-gradient(left, rgba(<?php echo $startcolor; ?>) 0%, rgba(<?php echo $endcolor; ?>) 100%); /* Opera 11.10+ */
		background: -ms-linear-gradient(left, rgba(<?php echo $startcolor; ?>) 0%, rgba(<?php echo $endcolor; ?>) 100%); /* IE10+ */
		background: linear-gradient(left, rgba(<?php echo $startcolor; ?>) 0%, rgba(<?php echo $endcolor; ?>) 100%); /* W3C */
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='<?php echo TilesHelperUtils::rgb2html($startcolor); ?>', endColorstr='<?php echo TilesHelperUtils::rgb2html($endcolor); ?>', GradientType=1); /* IE6-9 */
	}

	.tiles_right_control {
		position: absolute;
		z-index: 4;
		width: 10%;
		left: 91%;
		top: 0;
		cursor: pointer;
		background: -moz-linear-gradient(left, rgba(<?php echo $endcolor; ?>) 0%, rgba(<?php echo $startcolor; ?>) 100%); /* FF3.6+ */
		background: -webkit-gradient(linear, left top, right top, color-stop(0%, rgba(<?php echo $endcolor; ?>)), color-stop(100%, rgba(<?php echo $startcolor; ?>))); /* Chrome,Safari4+ */
		background: -webkit-linear-gradient(left, rgba(<?php echo $endcolor; ?>) 0%, rgba(<?php echo $startcolor; ?>) 100%); /* Chrome10+,Safari5.1+ */
		background: -o-linear-gradient(left, rgba(<?php echo $endcolor; ?>) 0%, rgba(<?php echo $startcolor; ?>) 100%); /* Opera 11.10+ */
		background: -ms-linear-gradient(left, rgba(<?php echo $endcolor; ?>) 0%, rgba(<?php echo $startcolor; ?>) 100%); /* IE10+ */
		background: linear-gradient(left, rgba(<?php echo $endcolor; ?>) 0%, rgba(<?php echo $startcolor; ?>) 100%); /* W3C */
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='<?php echo TilesHelperUtils::rgb2html($endcolor); ?>', endColorstr='<?php echo TilesHelperUtils::rgb2html($startcolor); ?>', GradientType=1); /* IE6-9 00ffffff */
	}

	.btn_scroll_left {
		background: none !important;
	}

	.btn_scroll_right {
		background: none !important;
	}

	.btn_scroll_left:hover {
		background: url(<?php echo JURI::root(); ?>media/mod_tiles/templates/default/images/left_arrow_<?php echo $iconcolor; ?>.png) no-repeat !important;
		background-position: 30% center !important;
	}

	.btn_scroll_right:hover {
		background: url(<?php echo JURI::root(); ?>media/mod_tiles/templates/default/images/right_arrow_<?php echo $iconcolor; ?>.png) no-repeat !important;
		background-position: 70% center !important;
	}

	.aTile_inner {
		padding: <?php echo $padding; ?>px;
		margin: <?php echo $margin; ?>px;
		display: block;
	}
</style>
<script type="text/javascript">
	(function ($) {
		$(document).ready(function ($) {
			$("div#tiles_holder_<?php echo $module->id;?>").tiles({
				maxLeft: -<?php echo $maxleft; ?>,
				effect: <?php echo $effect ?>
			});
		});
	})(jQuery);
</script>
<div id="tiles_holder_<?php echo $module->id;?>" class="tiles_holder"
     style="width: <?php echo TilesHelperUtils::getGallerySetting($params->get('tilesid', 1), 'tiles_width', 100); ?>%;
	     height: <?php echo TilesHelperUtils::getGallerySetting($params->get('tilesid', 1), 'tiles_height', 300); ?>px; position: relative;">

	<div class="tiles_scroller"
	     style="width: <?php echo modTilesHelper::getTileShowWidth($params->get('tilesid', 1)); ?>%;
		     height: <?php echo TilesHelperUtils::getGallerySetting($params->get('tilesid', 1), 'tiles_height', 300); ?>px;
		     left: <?php echo $params->get('start_position', -200); ?>px;">
		<?php
		for ($i = 0; $i < count($tiles); $i++)
		{
			$color = "";
			$tile  = $tiles[$i];

			// Check if tile is placed
			if (!empty($tile->position))
			{
				?>
				<div id="tile_<?php echo $tile->id; ?>" class="aTile"
				     style="<?php echo modTilesHelper::getATileStyle($tile); ?>">
					<div class="aTile_holder">
						<div class="aTile_inner" style="<?php echo modTilesHelper::getATileInnerStyle($tile); ?>">
							<?php if (!empty($tile->fontcolor))
							{
								// Optimize
								$color = "style=\"color: " . $tile->fontcolor . "\"";
							}?>
							<span <?php echo $color; ?>>
							<h2><?php echo $tile->title; ?></h2>
							<p>
							<?php echo JHTML::_('content.prepare', $tile->text); ?>
							</p>
							</span>
							<?php if (!empty($tile->overlay) && $tile->overlay != 'none')
							{ ?>
								<div class="tiles_overlay"
								     style="background: <?php echo modTilesHelper::getATileOverlay($tile->overlay); ?>;"></div>
							<?php } ?>
							<?php
							// Link
							echo modTilesHelper::getATileLink($tile);
							?>
						</div>
					</div>
				</div>
			<?php
			}
		}
		?>
	</div>
	<div class="tiles_left_control"
	     style="height: <?php echo TilesHelperUtils::getGallerySetting($params->get('tilesid', 1),
		     'tiles_height', 300); ?>px;">
		<a class="btn_scroll_left"></a>
	</div>
	<div class="tiles_right_control"
	     style="height: <?php echo TilesHelperUtils::getGallerySetting($params->get('tilesid', 1),
		     'tiles_height', 300); ?>px;">
		<a class="btn_scroll_right"></a>
	</div>
</div>
<?php
if ($params->get('powered_by', 1))
{
	echo TilesHelperBasic::getFooterText();
}
