<?php
/**
 * @package    Tiles
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       23.11.13
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com - Yves Hoppe. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */
defined('_JEXEC') or die('Restricted access');

/**
 * Script file of Tiles component
 *
 * @since  1.0.0
 */
class Com_TilesInstallerScript
{
	private $installationQueue = array(
		'free' => array(
			'modules' => array(
				'site' => array(
					'mod_tiles' => array('left', 0)
				)
			)
		),
		'pro' => array(
			'plugins' => array(
				'plg_installer_tiles' => 1
			)
		),
		// Key is the name without the lib_ prefix, value if the library should be autopublished
		'libraries' => array(
			'compojoom' => 1
		)
	);

	/**
	 * Executed on install/update/discover
	 *
	 * @param   string                      $type    - the type of th einstallation
	 * @param   JInstallerAdapterComponent  $parent  - the parent JInstaller obeject
	 *
	 * @return boolean - true if everything is OK and we should continue with the installation
	 */
	public function preflight($type, $parent)
	{
		$path = $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/include.php';

		require_once $path;

		// Load the installer files that come with our package - in case the library is already loaded on the page
		// The library can be loaded if updating using liveupdate, or if any plugin on the page is active
		JLoader::register('CompojoomInstaller', $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/installer/installer.php', true);
		JLoader::register('CompojoomInstallerCb', $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/installer/cb.php', true);
		JLoader::register('CompojoomInstallerAup', $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/installer/aup.php', true);
		JLoader::register('CompojoomDatabaseInstaller', $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/database/installer.php', true);

		$this->installer = new CompojoomInstaller($type, $parent, 'com_tiles');

		if (!$this->installer->allowedInstall())
		{
			return false;
		}

		return true;
	}

	/**
	 * Method to uninstall the component
	 *
	 * @param   object  $parent  - The parent
	 *
	 * @return  void
	 */
	public function uninstall($parent)
	{
		require_once JPATH_LIBRARIES . '/compojoom/include.php';

		$this->installer = new CompojoomInstaller('uninstall', $parent, 'com_tiles');

		$this->status = new stdClass;
		require_once JPATH_ADMINISTRATOR . '/components/com_tiles/version.php';

		// Let us install the modules & plugins
		$this->status->modules = $this->installer->uninstallModules($this->installationQueue['free']['modules']);

		echo $this->displayInfoUninstallation();
	}

	/**
	 * method to run after an install/update/discover method
	 *
	 * @param   int     $type    - The type
	 * @param   object  $parent  - The parent
	 *
	 * @return void
	 */
	public function postflight($type, $parent)
	{
		$path = $parent->getParent()->getPath('source');
		require_once $path . '/administrator/components/com_tiles/version.php';
		$this->status = new stdClass;

		$dbInstaller = new CompojoomDatabaseInstaller(
			array(
				'dbinstaller_directory' => $path . '/administrator/components/com_tiles/sql/xml'
			)
		);
		$dbInstaller->updateSchema();

		// Don't install the "Installer - Hotspots" plugin for Joomla! 3.0.0+
		if (!TILES_PRO && version_compare(JVERSION, '3.0.0', 'ge'))
		{
			if (isset($this->installationQueue['pro']['plugins']['plg_installer_tiles']))
			{
				unset($this->installationQueue['pro']['plugins']['plg_installer_tiles']);
			}
		}

		$this->status = new stdClass;
		$this->status->modules = $this->installer->installModules($this->installationQueue['free']['modules']);
		$this->status->libraries = $this->installer->installLibraries($this->installationQueue['libraries']);

		if (TILES_PRO)
		{
			$this->status->plugins = $this->installer->installPlugins($this->installationQueue['pro']['plugins']);
		}

		echo $this->displayInfoInstallation();

	}

	/**
	 * Displays the uninstall Informations
	 *
	 * @return  string
	 */
	private function displayInfoUninstallation()
	{
		$html[] = JText::_('COM_TILES_COMPLETE_UNINSTALL');

		$html[] = $this->installer->renderModuleInfoUninstall($this->status->modules);
		$html[] = CompojoomHtmlTemplates::renderSocialMediaInfo();

		return implode('', $html);
	}

	/**
	 * Display the Installation info
	 *
	 * @return  string
	 */
	private function displayInfoInstallation()
	{
		$html[] = '<strong>' . JText::_('COM_TILES_XML_DESCRIPTION') . '</strong><br /><br />';
		$html[] = '<div class="header">' . JText::_('COM_TILES_INSTALLATION_SUCCESS') . '</div>';
		$html[] = '<img src="' . JURI::root() . 'media/com_tiles/backend/images/logo.png" />';
		$html[] = "<br /><strong>Thank you for installing Tiles!</strong><br /><br />";
		$html[] = '<p>' . JText::_('COM_TILES_INSTALLATION_DOC_FORUMS_FIND') . ': ';
		$html[] = '<a href="http://www.compojoom.com" target="_blank">http://compojoom.com</a>';
		$html[] = '<p></p><strong>';
		$html[] = JText::_('COM_TILES_INSTALLATION_QUICK_INSTRUCTIONS') . '<br />';
		$html[] = '</strong></p>';
		$html[] = '<div><ol><li>';
		$html[] = JText::_('COM_TILES_INSTALLATION_CREATE_A_GALLERY');
		$html[] = '(<a href="' . JRoute::_('index.php?option=com_tiles&view=galleries') . '"
            target="_blank">' . JText::_('COM_TILES_INSTALLATION_CLICK_HERE') . '</a>)';
		$html[] = '</li><li>';
		$html[] = JText::_('COM_TILES_INSTALLATION_CREATE_SOME_TILES')
			. '(<a href="' . JRoute::_('index.php?option=com_tiles&controller=elements&task=edit')
			. '" target="_blank">' . JText::_('COM_TILES_INSTALLATION_CLICK_HERE') . '</a>)';
		$html[] = '</li></ol></div>';
		$html[] = CompojoomHtmlTemplates::renderSocialMediaInfo();

		if ($this->status->libraries)
		{
			$html[] = $this->installer->renderLibraryInfoInstall($this->status->libraries);
		}

		if ($this->status->modules)
		{
			$html[] = $this->installer->renderModuleInfoInstall($this->status->modules);
		}

		if ($this->status->plugins)
		{
			$html[] = $this->installer->renderPluginInfoInstall($this->status->plugins);
		}

		return implode('', $html);
	}
}
